@@ -58,17 +58,17 @@ class TSDatabase():
     def _create_view_class(self, base):
         class View(base):
             __tablename__ = 'views'
-            time = COLUMN(TIMESTAMP, primary_key=True)
-            movie_id = COLUMN(Text)
-            user_id = COLUMN(Text, primary_key=True)
-            minute = COLUMN(Integer)
+            time = Column(TIMESTAMP, primary_key=True)
+            movie_id = Column(Text)
+            user_id = Column(Text, primary_key=True)
+            minute = Column(Integer)
         return View
     
     def _create_rating_class(self, base):
         class Rating(base):
             __tablename__ = 'views'
-            time = COLUMN(TIMESTAMP, primary_key=True)
-            movie_id = COLUMN(Text)
-            user_id = COLUMN(Text, primary_key=True)
-            rating = COLUMN(SmallInteger)
+            time = Column(TIMESTAMP, primary_key=True)
+            movie_id = Column(Text)
+            user_id = Column(Text, primary_key=True)
+            rating = Column(SmallInteger)
         return Rating
\ No newline at end of file
